@@ -1,7 +1,9 @@
 mod math;
 mod perf;
 mod profiler;
+mod string;
 
 pub use math::*;
 pub use perf::*;
 pub use profiler::*;
+pub use string::*;
